@@ -158,7 +158,6 @@ fcpattern_to_gp_font_entry (FcPattern *font)
 
 	result = FcPatternGetBool (font, FC_OUTLINE, 0, &outline);
 	if (!outline)
-		/* We only care about outline fonts */
 		return NULL;
 
 	result = FcPatternGetString (font, FC_FAMILY, 0, &fc_family);
@@ -193,8 +192,11 @@ fcpattern_to_gp_font_entry (FcPattern *font)
 		font_type = GP_FONT_ENTRY_TYPE1;
 	else if (strcasecmp (c, ".ttf") == 0)
 		font_type = GP_FONT_ENTRY_TRUETYPE;
-	else
+	else if (strcasecmp (c, ".font") == 0) /* See #102400 */
+		font_type = GP_FONT_ENTRY_TRUETYPE;
+	else {
 		return NULL;
+	}
 
 	e = g_new0 (GPFontEntry, 1);
 	e->type         = font_type;
@@ -206,6 +208,7 @@ fcpattern_to_gp_font_entry (FcPattern *font)
 	e->familyname   = g_strdup (fc_family);
 	e->name         = g_strdup_printf ("%s %s", e->familyname, e->weight);
 	e->italic_angle = italic_angle;
+	e->is_alias     = FALSE;
 	
 	result = FcPatternGetInteger (font, FC_WEIGHT, 0, &weight);
 	if (result == FcResultMatch)
@@ -217,60 +220,87 @@ fcpattern_to_gp_font_entry (FcPattern *font)
 }
 
 static GPFontEntry *
-fcpattern_to_gp_font_entry_alias (FcPattern *font, const gchar *family, const gchar *style)
+fcpattern_to_gp_font_entry_alias (FcPattern *font, const gchar *name)
 {
 	GPFontEntry *e;
+
 	e = fcpattern_to_gp_font_entry (font);
 	if (e == NULL)
 		return NULL;
 
 	my_g_free (e->name);
-	e->name   = g_strdup_printf ("%s %s", family, style);
-
+	e->name   = g_strdup (name);
+	e->is_alias = TRUE;
+	   
 	return e;
 }
 
-/* Add well-known aliases Sans Sans-Serif and Monospace */
+typedef struct {
+	const gchar *name;
+	const gchar *family;
+	gint slant;
+	gint weight;
+} GPAliasInfo;
+
+/**
+ * gp_fontmap_add_aliases:
+ * @map: 
+ * 
+ * Add well known aliases to our fontmap
+ **/
 static void
 gp_fontmap_add_aliases (GPFontMap *map)
 {
 	FcPattern *match_pattern, *result_pattern;
 	GPFontEntry *e;
-	gchar *aliases[] = { "Sans", "Serif", "Monospace", NULL };
-	gchar *styles[] = { "Regular", "Bold", "Italic", "Bold Italic", NULL };
+	GPAliasInfo aliases[] = {
+		{ "Sans Regular",          "sans-serif", FC_SLANT_ROMAN,  FC_WEIGHT_MEDIUM },
+		{ "Sans Bold",             "sans-serif", FC_SLANT_ROMAN,  FC_WEIGHT_BOLD },
+		{ "Sans Italic",           "sans-serif", FC_SLANT_ITALIC, FC_WEIGHT_MEDIUM },
+		{ "Sans Bold Italic",      "sans-serif", FC_SLANT_ITALIC, FC_WEIGHT_BOLD },
+		{ "Serif Regular",         "serif",      FC_SLANT_ROMAN,  FC_WEIGHT_MEDIUM },
+		{ "Serif Bold",            "serif",      FC_SLANT_ROMAN,  FC_WEIGHT_BOLD },
+		{ "Serif Italic",          "serif",      FC_SLANT_ITALIC, FC_WEIGHT_MEDIUM },
+		{ "Serif Bold Italic",     "serif",      FC_SLANT_ITALIC, FC_WEIGHT_BOLD },
+		{ "Monospace Regular",     "monospace",  FC_SLANT_ROMAN,  FC_WEIGHT_MEDIUM },
+		{ "Monospace Bold",        "monospace",  FC_SLANT_ROMAN,  FC_WEIGHT_BOLD },
+		{ "Monospace Italic",      "monospace",  FC_SLANT_ITALIC, FC_WEIGHT_MEDIUM },
+		{ "Monospace Bold Italic", "monospace",  FC_SLANT_ITALIC, FC_WEIGHT_BOLD },
+		{ NULL }
+	};
 	FcResult res;
-	gint i, j;
+	gint i;
 
-	/* If no fonts could be loaded, we can't create aliases */
-	if (map == NULL)
-		return;
+	for (i = 0; aliases[i].name; i++) {
+		match_pattern = FcPatternBuild (NULL,
+						FC_FAMILY, FcTypeString,  aliases[i].family,
+						FC_SLANT,  FcTypeInteger, aliases[i].slant,
+						FC_WEIGHT, FcTypeInteger, aliases[i].weight,
+						NULL);
+		FcConfigSubstitute (NULL, match_pattern, FcMatchPattern);
+		FcDefaultSubstitute (match_pattern);
 
-	for (i = 0; aliases[i]; i++) {
-		for (j = 0; styles[j]; j++) {
-			match_pattern = FcPatternBuild (NULL,
-							FC_FAMILY, FcTypeString, aliases[i],
-							FC_STYLE,  FcTypeString, styles[j],
-							NULL);
-
-			FcConfigSubstitute (NULL, match_pattern, FcMatchPattern);
-			FcDefaultSubstitute (match_pattern);
-
-			g_assert (match_pattern);
-
-			result_pattern = FcFontMatch (NULL, match_pattern, &res);
-			if (result_pattern) {
-				e = fcpattern_to_gp_font_entry_alias (result_pattern, aliases[i], styles[j]);
-				if (e) {
-					g_hash_table_insert (map->fontdict, e->name, e);
-					map->num_fonts++;
-					map->fonts = g_slist_prepend (map->fonts, e);
-				}
-
-				FcPatternDestroy (result_pattern);
-			}
-
-			FcPatternDestroy (match_pattern);
+		if (!match_pattern) {
+			g_warning ("Could not create match patern for alias %s\n", aliases[i].name);
+			continue;
 		}
+		
+		result_pattern = FcFontMatch (NULL, match_pattern, &res);
+
+		if (!result_pattern) {
+			g_warning ("Could not create result patern for alias %s\n", aliases[i].name);
+			FcPatternDestroy (match_pattern);
+			continue;
+		}
+		
+		e = fcpattern_to_gp_font_entry_alias (result_pattern, aliases[i].name);
+		if (e) {
+			g_hash_table_insert (map->fontdict, e->name, e);
+			map->num_fonts++;
+			map->fonts = g_slist_prepend (map->fonts, e);
+		}
+		FcPatternDestroy (result_pattern);
+		FcPatternDestroy (match_pattern);
 	}
 }
 
@@ -299,23 +329,12 @@ gp_fontmap_load_fontconfig (GPFontMap *map)
 	}
 }
 
-static GPFontMap *
-gp_fontmap_load (void)
+static void
+gp_fontmap_sort (GPFontMap *map)
 {
-	GPFontMap *map;
 	GSList * l;
 
-	map = g_new0 (GPFontMap, 1);
-	/* We always hold private ref to fontmap, this is released if directories change */
-	map->refcount = 1;
-	map->num_fonts = 0;
-	map->fontdict     = g_hash_table_new (g_str_hash, g_str_equal);
-	map->familydict   = g_hash_table_new (g_str_hash, g_str_equal);
-
-	gp_fontmap_load_fontconfig (map);
-	gp_fontmap_add_aliases (map);
-
-	/* Sort fonts alphabetically */
+	/* Sort fonts */
 	map->fonts = g_slist_sort (map->fonts, gp_fe_sortname);
 
 	/* Sort fonts into familia */
@@ -345,16 +364,32 @@ gp_fontmap_load (void)
 		f = (GPFamilyEntry *) l->data;
 		f->fonts = g_slist_sort (f->fonts, gp_fe_sortspecies);
 	}
+}
+
+
+static GPFontMap *
+gp_fontmap_load (void)
+{
+	GPFontMap *map;
+
+	map = g_new0 (GPFontMap, 1);
+	map->refcount  = 1;
+	map->num_fonts = 0;
+	map->fontdict   = g_hash_table_new (g_str_hash, g_str_equal);
+	map->familydict = g_hash_table_new (g_str_hash, g_str_equal);
+
+	gp_fontmap_load_fontconfig (map);
+	if (map->fonts == NULL) {
+		g_warning ("No fonts could be loaded into fontmap.");
+		return map;
+	}
+
+	gp_fontmap_add_aliases (map);
+	gp_fontmap_sort (map);
 
 	return map;
 }
 
-/*
- * Font Entry stuff
- *
- * If face is created, it has to reference an entry
- */
-
 void
 gp_font_entry_ref (GPFontEntry * entry)
 {
@@ -445,7 +480,8 @@ gnome_font_family_list ()
 			map->familylist = g_list_prepend (map->familylist, f->name);
 		}
 		map->familylist = g_list_reverse (map->familylist);
-		if (!familylist2map) familylist2map = g_hash_table_new (NULL, NULL);
+		if (!familylist2map)
+			familylist2map = g_hash_table_new (NULL, NULL);
 		g_hash_table_insert (familylist2map, map->familylist, map);
 	}
 
@@ -502,35 +538,35 @@ gp_fontmap_lookup_weight (const gchar * weight)
 		weights = g_hash_table_new (g_str_hash, g_str_equal);
 
 		g_hash_table_insert (weights, "Extra Light", GINT_TO_POINTER (GNOME_FONT_EXTRA_LIGHT));
-		g_hash_table_insert (weights, "Extralight", GINT_TO_POINTER (GNOME_FONT_EXTRA_LIGHT));
+		g_hash_table_insert (weights, "Extralight",  GINT_TO_POINTER (GNOME_FONT_EXTRA_LIGHT));
 
-		g_hash_table_insert (weights, "Thin", GINT_TO_POINTER (GNOME_FONT_THIN));
+		g_hash_table_insert (weights, "Thin",        GINT_TO_POINTER (GNOME_FONT_THIN));
 
-		g_hash_table_insert (weights, "Light", GINT_TO_POINTER (GNOME_FONT_LIGHT));
+		g_hash_table_insert (weights, "Light",       GINT_TO_POINTER (GNOME_FONT_LIGHT));
 
-		g_hash_table_insert (weights, "Book", GINT_TO_POINTER (GNOME_FONT_BOOK));
-		g_hash_table_insert (weights, "Roman", GINT_TO_POINTER (GNOME_FONT_BOOK));
-		g_hash_table_insert (weights, "Regular", GINT_TO_POINTER (GNOME_FONT_BOOK));
+		g_hash_table_insert (weights, "Book",        GINT_TO_POINTER (GNOME_FONT_BOOK));
+		g_hash_table_insert (weights, "Roman",       GINT_TO_POINTER (GNOME_FONT_BOOK));
+		g_hash_table_insert (weights, "Regular",     GINT_TO_POINTER (GNOME_FONT_BOOK));
 
-		g_hash_table_insert (weights, "Medium", GINT_TO_POINTER (GNOME_FONT_MEDIUM));
+		g_hash_table_insert (weights, "Medium",      GINT_TO_POINTER (GNOME_FONT_MEDIUM));
 
-		g_hash_table_insert (weights, "Semi", GINT_TO_POINTER (GNOME_FONT_SEMI));
-		g_hash_table_insert (weights, "Semibold", GINT_TO_POINTER (GNOME_FONT_SEMI));
-		g_hash_table_insert (weights, "Demi", GINT_TO_POINTER (GNOME_FONT_SEMI));
-		g_hash_table_insert (weights, "Demibold", GINT_TO_POINTER (GNOME_FONT_SEMI));
+		g_hash_table_insert (weights, "Semi",        GINT_TO_POINTER (GNOME_FONT_SEMI));
+		g_hash_table_insert (weights, "Semibold",    GINT_TO_POINTER (GNOME_FONT_SEMI));
+		g_hash_table_insert (weights, "Demi",        GINT_TO_POINTER (GNOME_FONT_SEMI));
+		g_hash_table_insert (weights, "Demibold",    GINT_TO_POINTER (GNOME_FONT_SEMI));
 
-		g_hash_table_insert (weights, "Bold", GINT_TO_POINTER (GNOME_FONT_BOLD));
+		g_hash_table_insert (weights, "Bold",        GINT_TO_POINTER (GNOME_FONT_BOLD));
 
-		g_hash_table_insert (weights, "Heavy", GINT_TO_POINTER (GNOME_FONT_HEAVY));
+		g_hash_table_insert (weights, "Heavy",       GINT_TO_POINTER (GNOME_FONT_HEAVY));
  
-		g_hash_table_insert (weights, "Extra", GINT_TO_POINTER (GNOME_FONT_EXTRABOLD));
-		g_hash_table_insert (weights, "Extra Bold", GINT_TO_POINTER (GNOME_FONT_EXTRABOLD));
+		g_hash_table_insert (weights, "Extra",       GINT_TO_POINTER (GNOME_FONT_EXTRABOLD));
+		g_hash_table_insert (weights, "Extra Bold",  GINT_TO_POINTER (GNOME_FONT_EXTRABOLD));
 
-		g_hash_table_insert (weights, "Black", GINT_TO_POINTER (GNOME_FONT_BLACK));
+		g_hash_table_insert (weights, "Black",       GINT_TO_POINTER (GNOME_FONT_BLACK));
 
 		g_hash_table_insert (weights, "Extra Black", GINT_TO_POINTER (GNOME_FONT_EXTRABLACK));
-		g_hash_table_insert (weights, "Extrablack", GINT_TO_POINTER (GNOME_FONT_EXTRABLACK));
-		g_hash_table_insert (weights, "Ultra Bold", GINT_TO_POINTER (GNOME_FONT_EXTRABLACK));
+		g_hash_table_insert (weights, "Extrablack",  GINT_TO_POINTER (GNOME_FONT_EXTRABLACK));
+		g_hash_table_insert (weights, "Ultra Bold",  GINT_TO_POINTER (GNOME_FONT_EXTRABLACK));
 	};
 
 	wcode = GPOINTER_TO_INT (g_hash_table_lookup (weights, weight));
