@@ -23,7 +23,8 @@
  *  Copyright 2000-2003 Ximian, Inc.
  *
  *  References:
- *    Document Structuring Conventions, Adobe. [http://partners.adobe.com/asn/developer/pdfs/tn/5001.DSC_Spec.pdf]
+ *    [1] Postscript Language Reference, 3rd Edition. Adobe. [http://partners.adobe.com/asn/developer/pdfs/tn/PLRM.pdf]
+ *    [2] Document Structuring Conventions, Adobe. [http://partners.adobe.com/asn/developer/pdfs/tn/5001.DSC_Spec.pdf]
  */
 
 #include <config.h>
@@ -304,7 +305,6 @@ gnome_print_ps2_clip (GnomePrintContext *ctx, const ArtBpath *bpath, ArtWindRule
 
 	ps2 = GNOME_PRINT_PS2 (ctx);
 
-	/* FIXME, do we not have to set the line and color atributes here? (Chema) */
 	ret = gnome_print_ps2_print_bpath (ps2, bpath);
 	g_return_val_if_fail (ret >= 0, ret);
 
@@ -325,7 +325,6 @@ gnome_print_ps2_fill (GnomePrintContext *ctx, const ArtBpath *bpath, ArtWindRule
 
 	ps2 = GNOME_PRINT_PS2 (ctx);
 
-	/* FIXME, do we not have to set the line and color atributes here? (Chema) */
 	ret += gnome_print_ps2_set_color (ps2);
 	ret += gnome_print_ps2_print_bpath (ps2, bpath);
 
@@ -599,19 +598,16 @@ gnome_print_ps2_close (GnomePrintContext *pc)
 	}
 
 	/* Do header */
-	/* Comments */
 	date = gnome_print_ps2_get_date ();
-	gnome_print_transport_printf (pc->transport, "%%!PS-Adobe-3.0" EOL);
-	/* fixme: %%BoundingBox: */
+	gnome_print_transport_printf (pc->transport, "%%!PS-Adobe-3.0" EOL);	
+	/* DSC Comments */
 	gnome_print_transport_printf (pc->transport, "%%%%Creator: Gnome Print Version %s" EOL, VERSION);
 	gnome_print_transport_printf (pc->transport, "%%%%CreationDate: %s" EOL, date);
-	/* fixme: %%DocumentData: */
-	/* fixme: Should we use %%Extensions: and drop LanguageLevel? */
 	gnome_print_transport_printf (pc->transport, "%%%%LanguageLevel: 2" EOL);
 	gnome_print_transport_printf (pc->transport, "%%%%DocumentMedia: Regular %d %d 0 () ()" EOL,
 				      (gint) (ps2->bbox.x1 - ps2->bbox.x0), (gint) (ps2->bbox.y1 - ps2->bbox.y0));
 
-	/* Orientation */
+	/* Orientation ([2] Page 43) */
 	gnome_print_transport_printf (pc->transport, "%%%%Orientation: ");
 	orientation = gnome_print_config_get (pc->config, GNOME_PRINT_KEY_ORIENTATION);
 	if (!orientation || strcmp ("R0", orientation) == 0) {
@@ -619,11 +615,11 @@ gnome_print_ps2_close (GnomePrintContext *pc)
 	} else if (strcmp ("R90", orientation) == 0) {
 		gnome_print_transport_printf (pc->transport, "Landscape");
 	} else if (strcmp ("R180", orientation) == 0) {
-		gnome_print_transport_printf (pc->transport, "Reverse Portrait");
+		gnome_print_transport_printf (pc->transport, "Portrait");
 	} else if (strcmp ("R270", orientation) == 0) {
-		gnome_print_transport_printf (pc->transport, "Reverse Landscape");
+		gnome_print_transport_printf (pc->transport, "Landscape");
 	} else {
-		g_warning ("Could not interpret Orientation from GnomePrintConfig [%s]<-\n", orientation);
+		g_warning ("Could not interpret Orientation from GnomePrintConfig [%s]\n", orientation);
 	}
 	g_free (orientation);
 	gnome_print_transport_printf (pc->transport, EOL);
@@ -678,7 +674,6 @@ gnome_print_ps2_close (GnomePrintContext *pc)
 	gnome_print_transport_printf (pc->transport, "<<" EOL);
 	gnome_print_transport_printf (pc->transport, "/PageSize [%d %d]" EOL, (gint) (ps2->bbox.x1 - ps2->bbox.x0), (gint) (ps2->bbox.y1 - ps2->bbox.y0));
 	gnome_print_transport_printf (pc->transport, "/ImagingBBox null" EOL);
-	gnome_print_transport_printf (pc->transport, "/Orientation %d" EOL, 0); /* FIXME: real orientation */
 	gnome_print_transport_printf (pc->transport, ">> setpagedevice" EOL);
 	/* Download fonts */
 	for (font = ps2->fonts; font != NULL; font = font->next) {
